@@ -36,10 +36,12 @@
 #
 ##########################################################################################
 
-
-if(scalar(@ARGV)==0 || ! -e $ARGV[0] ){
+if(scalar(@ARGV)<1){
 	print STDERR "USAGE: proteinortho2html.pl <myproject.proteinortho> (<fasta1> <fasta2> ...)\nthe first argument points to the proteinortho output (tsv)-file. Any further (optional) files should be fasta files, for conversion of the identifier to a proper gene name/ describtion. The HTML output is printed to stdout, use '>' to write the html output to a file.\n";
 	exit 1;
+}elsif($ARGV[0] =~m/-he?l?p?$/){
+	print STDERR "USAGE: proteinortho2html.pl <myproject.proteinortho> (<fasta1> <fasta2> ...)\nthe first argument points to the proteinortho output (tsv)-file. Any further (optional) files should be fasta files, for conversion of the identifier to a proper gene name/ describtion. The HTML output is printed to stdout, use '>' to write the html output to a file.\n";
+	exit 0;
 }
 
 #
@@ -47,8 +49,11 @@ if(scalar(@ARGV)==0 || ! -e $ARGV[0] ){
 #
 
 my %mappingdata;
+my $proteinorthotsvfile;
 	
-for(my $argi=1;$argi<scalar(@ARGV);$argi++){
+for(my $argi=0;$argi<scalar(@ARGV);$argi++){
+	if($ARGV[$argi]=~m/\.tsv/){$proteinorthotsvfile=$ARGV[$argi];next;}
+	if($ARGV[$argi]=~m/proteinortho2html/){next;}
 	open(FILE,"<",$ARGV[$argi]);
 	while(<FILE>){
 		if(substr($_,0,1) ne ">"){next;}
@@ -71,6 +76,10 @@ for(my $argi=1;$argi<scalar(@ARGV);$argi++){
 	close(FILE);
 }
 
+if(!-e $proteinorthotsvfile){
+	print STDERR "USAGE: proteinortho2html.pl <myproject.proteinortho> (<fasta1> <fasta2> ...)\nthe first argument points to the proteinortho output (tsv)-file. Any further (optional) files should be fasta files, for conversion of the identifier to a proper gene name/ describtion. The HTML output is printed to stdout, use '>' to write the html output to a file.\n";
+	exit 1;
+}
 
 #
 ## HEAD STUFF
@@ -82,7 +91,6 @@ print '<!DOCTYPE HTML>
   <head>
     <meta charset="UTF-8">
     <title>Proteinortho 6</title>
-
 	<script type="text/javascript">
 
 		// ***** clusterize.min.js ***** (source:https://github.com/NeXTs/Clusterize.js)
@@ -238,8 +246,16 @@ a!=c[b];c[b]=a;return d}};return p});
 		  color: #333333;
 		  text-align: center;
 
+		    position: -webkit-sticky;
+		    position: -moz-sticky; 
+		    position: -ms-sticky;
+		    position: -o-sticky;
+		    position: sticky;
+    		top: 0;
+    		z-index: 99;
 
 		}
+		
 		table.greyGridTable thead th:not(:nth-child(1)):not(:nth-child(2)):not(:nth-child(3)) {
 	      
 	      -webkit-transform: rotate(-0deg) translatex(-0%);
@@ -258,6 +274,7 @@ a!=c[b];c[b]=a;return d}};return p});
 		  white-space: nowrap;
 
 		}
+
 		table.greyGridTable thead th:nth-child(-n+2) (height > 10px) {
 
 	      -webkit-transform: rotate(-90deg) translatex(-0%);
@@ -328,9 +345,11 @@ a!=c[b];c[b]=a;return d}};return p});
 		}
 		.clusterize-scroll{
 		    position: absolute;
-		    top: 115px;
+		    top: 135px;
 		    left: 0;
 		    right: 0;
+		    padding:0;
+		    margin:0;
 		    bottom: 0;
 		    max-height: none; /* <-- important one  */
 		  	overflow: auto;
@@ -351,28 +370,45 @@ a!=c[b];c[b]=a;return d}};return p});
 		  text-align: center;
 		}
 		.overlay{
+		  padding:5px;
+		  background: #369;
 		  position:fixed;
 		  width:100%;
-		  padding-bottom:18px;
-		  border-bottom:2px solid #333333;
+		  height:100px;
 		}
 		.left{
-		    width: 250px;
+			width: 40%;
 		    background: rgb(255,255,255,0);
-		    float: left;		
-		}
-		.middleA {
-			width: 150px;
 		    float: left;	
-		    background: rgb(255,255,255,0);
+		    height:100%;
+		}
+		.middleA {    
+			background: #369;
+			width: 10%;
+		    height:90%;
+		    float: left;	
 		}
 		.middleB {
+		    background: #369;
 		    float: left;	
-		    margin-left:40px;
-		    background: rgb(255,255,255,0);
+		    height:90%;
+		    margin-left:5%;
+			width: 45%;
+		}
+		.middleA input{
+			width:100%
+		}
+		.middleA input[type="checkbox"]{
+			width:10px;
 		}
 		.sidewaysdiv {
-				    
+			border-radius: 5px 5px 5px 5px;
+	        user-select: none;
+	        -moz-user-select: none;
+	        -khtml-user-select: none;
+	        -webkit-user-select: none;
+	        -o-user-select: none;
+
 		    /* Rotate from top left corner (not default) */
 		    -webkit-transform-origin: 0 0;
 		    -moz-transform-origin:    0 0;
@@ -384,15 +420,15 @@ a!=c[b];c[b]=a;return d}};return p});
 		    -ms-transform:     rotate(90deg); 
 		    -o-transform:      rotate(90deg); 
 			  top:0px;
-			  left:0;
+			  left:-5px;
 			  font-size:14px;
 			  position: relative;
 			  
-		    background: #369;
-		    color: #fff;
+		    background: white;
+		    color: black;
 		    padding: 4px 5px;
 		    margin: 0 0 3px 0;
-		    width:50px;
+		    width:80px;
 		    height:16px;
 
 		  	text-align: center;
@@ -402,24 +438,23 @@ a!=c[b];c[b]=a;return d}};return p});
 			float: right;
 		    background: rgb(255,255,255,0);
 		}
-		.topnull {
-			top:0;
-	  		position: absolute;
-		}
 	    select {
 	      border: none;  box-shadow: 0px 2px 5px 1px rgba(0,0,0,0.3);
 		  border-radius: 3px;
 		  border-top-left-radius:0px;
 		  border-bottom-left-radius:0px;
-		  top:0;
+		  top:5px;
 		  position: absolute;
 	    }
+
+
 	    input {
 	      border: none;  box-shadow: 2px 2px 5px 1px rgba(0,0,0,0.3);
 	  	  border-radius: 3px;
 	    } 
 	    h3{
 	    	margin:4px;
+	    	z-index:9999;
 	    }
 	    span{
 	    	font-size:13px;
@@ -439,12 +474,15 @@ a!=c[b];c[b]=a;return d}};return p});
 
 		/* Modal Content/Box */
 		.modal-content {
+		   position:fixed;
 		  background-color: #fefefe;
 		  margin: 15% auto; /* 15% from the top and centered */
 		  padding: 20px;
+		  left:10%;
 		  border: 1px solid #888;
 		  width: 80%; /* Could be more or less, depending on screen size */
 		  word-break: break-all;
+		  z-index:999;
 		}
 
 		/* The Close Button */
@@ -465,25 +503,36 @@ a!=c[b];c[b]=a;return d}};return p});
 		    border-width: 1px;
 		}
 		a.tooltip {
-  position: relative;
-  text-decoration: none;
-}
+	        user-select: none;
+	        -moz-user-select: none;
+	        -khtml-user-select: none;
+	        -webkit-user-select: none;
+	        -o-user-select: none;
+		  position: relative;
+		  text-decoration: none;
+		}
 .tooltip {
-  position: absolute;
-  padding:10px;
-    right:20px;
-  top:20px;
-  font-size:10px;
-  width:400px;
-  z-level:99999;
-  background-color:yellow;
-  border-radius:10px;
-  animation-delay: 10s;
-    -webkit-animation: fadein 2s; /* Safari, Chrome and Opera > 12.1 */
-       -moz-animation: fadein 2s; /* Firefox < 16 */
-        -ms-animation: fadein 2s; /* Internet Explorer */
-         -o-animation: fadein 2s; /* Opera < 12.1 */
-            animation: fadein 2s;
+	position:fixed;
+	        user-select: none;
+	        -moz-user-select: none;
+	        -khtml-user-select: none;
+	        -webkit-user-select: none;
+	        -o-user-select: none;
+			  position: absolute;
+			  padding:10px;
+			    right:20px;
+			  top:0px;
+			  height:5px;
+			  font-size:10px;
+			  z-level:0;
+			  background-color:yellow;
+			  border-radius:0px 0px 15px 15px;
+			  animation-delay: 10s;
+			    -webkit-animation: fadein 2s; /* Safari, Chrome and Opera > 12.1 */
+			       -moz-animation: fadein 2s; /* Firefox < 16 */
+			        -ms-animation: fadein 2s; /* Internet Explorer */
+			         -o-animation: fadein 2s; /* Opera < 12.1 */
+			            animation: fadein 2s;
 }
 
 @keyframes fadein {
@@ -515,8 +564,7 @@ a!=c[b];c[b]=a;return d}};return p});
     to   { opacity: 1; }
 }
 
-
-	</style>
+</style>
   </head>
   <body>';
 
@@ -524,7 +572,7 @@ a!=c[b];c[b]=a;return d}};return p});
 ## Title
 #
 
-print '<h3>Proteinortho 6 : '.$ARGV[0].'</h3>';
+print '<h3>Proteinortho 6 : '.$proteinorthotsvfile.'</h3>';
 
 print '<div id="myModal" class="modal">
 
@@ -544,12 +592,12 @@ print '<div id="myModal" class="modal">
 #
 
 print '<div class="overlay" id="overlay"><div class="left"><input type="text" id="searchField" onchange="isEmpty()" onkeyup="this.onchange();" onpaste="this.onchange();" oninput="this.onchange();" placeholder="Search..">';
-print '<input type="button" onclick="filterTable(0)" value="search" id="searchbutton">';#<input type="button" onclick="filterTable(1)" value="exact search">
-print '<br><span>The search for <span id="countspanA"></span><br>results in <b><span id="countspanB"></span></b> groups.</span></div><div class="middleA"><div class="sidewaysdiv">manage</div><div class="topnull"><input type="button" onclick="toggleCols();" value="toggle selected columns" id="toggleColsButton"><br><input type="button" onclick="togglePlus();" value="toggle all (+) and (-)" id="togglePlusButton"><br><input type="checkbox" id="toggleShowTrueNames" name="toggleShowTrueNames"
-          onclick="toggleShowTrueNames();"><label id="toggleShowTrueNamesLabel" for="toggleShowTrueNames">show IDs only</label></div></div>
-<div class="middleB"><div class="sidewaysdiv">select</div><select data-placeholder="Begin typing a name to filter..." multiple class="chosen-select" name="test" id="select">
+print '<br><input type="button" onclick="filterTable(0)" value="search" id="searchbutton">';#<input type="button" onclick="filterTable(1)" value="exact search">
+print '<br><span>The search for <span id="countspanA"></span><br>results in <b><span id="countspanB"></span></b> groups.</span></div><div class="middleA"><div class="sidewaysdiv">manage</div><input type="button" onclick="toggleCols();" value="toggle columns" id="toggleColsButton"><br><input type="button" onclick="togglePlus();" value="toggle (+)" id="togglePlusButton"><br><input type="checkbox" id="toggleShowTrueNames" name="toggleShowTrueNames"
+          onclick="toggleShowTrueNames();"><label id="toggleShowTrueNamesLabel" for="toggleShowTrueNames">show IDs only</label></div>
+<div class="middleB"><div class="sidewaysdiv">select</div><select multiple data-placeholder="Begin typing a name to filter..." class="chosen-select no-scroll" name="test" id="select">
 ';
-	open(FILE,"<",$ARGV[0]);
+	open(FILE,"<",$proteinorthotsvfile);
 	while(<FILE>){
 		my $curline=$_;
 		my $i=0;
@@ -576,7 +624,7 @@ print '</select></div></div>';
 
 print '<div class="clusterize"><div id="scrollArea" class="clusterize-scroll"><table id="myTable" class="greyGridTable"><thead><tr class="data-heading">';
 
-	open(FILE,"<",$ARGV[0]);
+	open(FILE,"<",$proteinorthotsvfile);
 	while(<FILE>){
 		my $curline=$_;
 		my $i=0;
@@ -608,7 +656,7 @@ print '<div class="clusterize"><div id="scrollArea" class="clusterize-scroll"><t
 
 	print '<tfoot><tr>';
 
-	open(FILE,"<",$ARGV[0]);
+	open(FILE,"<",$proteinorthotsvfile);
 	while(<FILE>){
 		my $curline=$_;
 		my $i=0;
@@ -633,6 +681,7 @@ print '<div class="clusterize"><div id="scrollArea" class="clusterize-scroll"><t
 
 print '</table></div></div>';
 
+
 print '</body>';
 
 #
@@ -684,22 +733,22 @@ print '<script type="text/javascript">
 		    height = Math.max( B.scrollHeight, B.offsetHeight,H.clientHeight, H.scrollHeight, H.offsetHeight );
 		}
 		function mouseOver() {
-			table=document.getElementById(\'myTable\');
-			table.style.zIndex="-1";
-			select.style.zIndex="1";
-			select.style.height=(height-50)+"px";
-			overlay=document.getElementById(\'overlay\');
-			overlay.style.zIndex="1";
+			// table=document.getElementById(\'myTable\');
+			//table.style.zIndex="-1";
+			//select.style.zIndex="999";
+			//select.style.height=(height-50)+"px";
+			//overlay=document.getElementById(\'overlay\');
+			//overlay.style.zIndex="1";
 
 		}
 
 		function mouseOut() {
-			table=document.getElementById(\'myTable\');
-			table.style.zIndex="1";
-			select.style.zIndex="-1";
-			select.style.height="";
-			overlay=document.getElementById(\'overlay\');
-			overlay.style.zIndex="-1";
+			//table=document.getElementById(\'myTable\');
+			//table.style.zIndex="999";
+			//select.style.zIndex="1";
+			//select.style.height="";
+			//overlay=document.getElementById(\'overlay\');
+			//overlay.style.zIndex="-1";
 
 		}
 
@@ -755,7 +804,8 @@ print '<script type="text/javascript">
 		}
 
 		var data_raw = [';
-		open(FILE,"<",$ARGV[0]);
+
+		open(FILE,"<",$proteinorthotsvfile);
 		my $rowi=0;
 		while(<FILE>){
 			if($rowi==0){$rowi++;next;}
@@ -801,7 +851,7 @@ print '];
 		var data_raw_mapped = [';
 
 		if(scalar(keys(%mappingdata))>0){
-			open(FILE,"<",$ARGV[0]);
+			open(FILE,"<",$proteinorthotsvfile);
 			my $rowi=0;
 			while(<FILE>){
 				if($rowi==0){$rowi++;next;}
@@ -1017,8 +1067,8 @@ if(scalar(@ARGV)>1){
 	my $commonSuffix="";
 	if(scalar(@ARGV)>1){
 		$foundCommonPrefix=1;
-		$commonPrefix=$ARGV[1];
-		$commonSuffix=$ARGV[1];
+		$commonPrefix=$proteinorthotsvfile;
+		$commonSuffix=$proteinorthotsvfile;
 		$commonPrefix=~s/\/[^\/]*$/\//;
 		$commonSuffix=~s/.*\.([^.]+)$/$1/;
 		for(my $argi=2;$argi<scalar(@ARGV);$argi++){
