@@ -28,8 +28,8 @@
 # @author Paul Klemm
 # @email klemmp@staff.uni-marburg.de
 # @company Bioinformatics, University of Leipzig
-# @version 2
-# @date 11-07-2019
+# @version 3
+# @date 30-04-2020
 #
 ##########################################################################################
 
@@ -106,33 +106,34 @@ my $doregex=0;
 my $source=0;
 my $exact=0;
 my $del=',';
+my @ARGV_copy=@ARGV;
 
-my @ARGViddone=[];
-my $ARGViddone_counter=scalar(@ARGV);
-for(my $v = 0 ; $v < scalar @ARGV ; $v++){
-	$ARGViddone[$v]=1;
-	if($ARGV[$v] =~ m/--?(help|h)$/){$help=1;}
-	elsif($ARGV[$v] =~ m/^--?(tofiles|t)$/){$tofiles=1;}
-	elsif($ARGV[$v] =~ m/^--?(source|s)$/){$source=1;}
-	elsif($ARGV[$v] =~ m/^--?F=(.*)$/){$del=$1;}
-	elsif($ARGV[$v] =~ m/^--?E$/){$doregex=1;}
-	elsif($ARGV[$v] =~ m/^--?exact$/){$exact=1;}
-	elsif($ARGV[$v] =~ m/^-.+/){print $usage; print STDERR "ERROR: invalid option ".$ARGV[$v]."!\n\n";exit(1);}
-	elsif(!defined($query)){$query = $ARGV[$v];}
-	else{$ARGViddone[$v]=0;$ARGViddone_counter--;}
+my @ARGV_copyiddone=(1) x (scalar(@ARGV_copy));
+my $ARGV_copyiddone_counter=scalar(@ARGV_copy);
+for(my $v = 0 ; $v < scalar @ARGV_copy ; $v++){
+	$ARGV_copyiddone[$v]=1;
+	if($ARGV_copy[$v] =~ m/--?(help|h)$/){$help=1;}
+	elsif($ARGV_copy[$v] =~ m/^--?(tofiles|t)$/){$tofiles=1;}
+	elsif($ARGV_copy[$v] =~ m/^--?(source|s)$/){$source=1;}
+	elsif($ARGV_copy[$v] =~ m/^--?F=(.*)$/){$del=$1;}
+	elsif($ARGV_copy[$v] =~ m/^--?E$/){$doregex=1;}
+	elsif($ARGV_copy[$v] =~ m/^--?exact$/){$exact=1;}
+	elsif($ARGV_copy[$v] =~ m/^-.+/){print $usage; print STDERR "ERROR: invalid option ".$ARGV_copy[$v]."!\n\n";exit(1);}
+	elsif(!defined($query)){$query = $ARGV_copy[$v];}
+	else{$ARGV_copyiddone[$v]=0;$ARGV_copyiddone_counter--;}
 }
 if ($help){
     print $usage;
     exit(0);
 }
 my $fail="";
-if (scalar(@ARGV) == 0){
+if (scalar(@ARGV_copy) == 0){
     $fail.="ERROR: no arguments found!\n";
 }
 if (!defined($query)){
     $fail.="ERROR: no QUERY provided!\n";
 }
-if ( $ARGViddone_counter==scalar(@ARGV) ){
+if ( $ARGV_copyiddone_counter==scalar(@ARGV_copy) ){
     $fail.="ERROR: no FASTA files provided!\n";
 }
 if($fail){
@@ -148,22 +149,37 @@ my $genecounter=0;
 
 unless(open(my $FH,'<',$query)) {
 	if($query eq "-"){
-		foreach my $line (<>) 
+		foreach my $line (<STDIN>) 
 		{
-			my $linel="";
-			#if(!$doregex){$linel=quotemeta($line);}
-			if(length($linel)==0|| $linel eq ""){continue;}
-			#if($exact){$linel='\b'.$linel.'\b';}
-			$qdata{"___"}{$linel}=$linel;
-			$genecounter++;
+			$line=~s/[\r\n]+$//;
+
+			if(length($line)==0 || $line eq ""){next;}
+
+			my @sp = split(/\t/,$line);
+			if(substr($line,0,1) eq "#"){@filenames=@sp; next;}
+			if(scalar(@sp)>3){
+				for(my $v = 3 ; $v < scalar @sp ; $v++){
+					if($sp[$v] eq "*" || $sp[$v] eq ""){next;}
+					my @spp = split(",",$sp[$v]);
+					#if($exact){$sp[$v]='\b'.$sp[$v].'\b';}
+					for(my $vv = 0 ; $vv < scalar @spp ; $vv++){
+						#if(!$doregex && !$exact){$spp[$vv]=quotemeta($spp[$vv]);}
+						if($spp[$vv] eq "*" || $spp[$vv] eq ""){next;}
+
+						$qdata{"STDIN"}{$spp[$vv]}="STDIN.OrthoGroup".$orthogroupcounter;
+						$genecounter++;
+					}
+				}
+			}
+			$orthogroupcounter++;
 		}
 	}else{
 		my @sp = split($del,$query); 
 		for(my $v = 0 ; $v < scalar @sp ; $v++){
 			#if(!$doregex){$sp[$v]=quotemeta($sp[$v]);}
-			if(length($sp[$v])==0 || $sp[$v] eq ""){continue;}
+			if(length($sp[$v])==0 || $sp[$v] eq ""){next;}
 			#if($exact){$sp[$v]='\b'.$sp[$v].'\b';}
-			$qdata{"___"}{$sp[$v]}=$sp[$v];
+			$qdata{"STDIN"}{$sp[$v]}=$sp[$v];
 			$genecounter++;
 		}
 	}
@@ -215,33 +231,33 @@ my $genecounterfound=0;
 my $basename = "";
 my $numOfFastas=0;
 
-for(my $v = 0 ; $v < scalar @ARGV ; $v++){
-	if($ARGViddone[$v]){next;}
+for(my $v = 0 ; $v < scalar @ARGV_copy ; $v++){
+	if($ARGV_copyiddone[$v]){next;}
 	$numOfFastas++;
 }
 
 my $fastai=1;
 
-for(my $v = 0 ; $v < scalar @ARGV ; $v++){
+for(my $v = 0 ; $v < scalar @ARGV_copy ; $v++){
 
-	if($ARGViddone[$v]){next;}
+	if($ARGV_copyiddone[$v]){next;}
 
-	if($tofiles){print STDERR "[STDERR] ($fastai/$numOfFastas) : ";if($basename ne ""){print STDERR "Done reading $basename. "}print STDERR "Start reading the fasta file ".($ARGV[$v])."\n";}
+	if($tofiles){print STDERR "[STDERR] ($fastai/$numOfFastas) : ";if($basename ne ""){print STDERR "Done reading $basename. "}print STDERR "Start reading the fasta file ".($ARGV_copy[$v])."\n";}
 	$fastai++;
 
-	$basename= $ARGV[$v];
+	$basename = $ARGV_copy[$v];
 	if($basename =~ m/\/([^\/]+)$/){
 		$basename=$1;
 	}
 
-	open(my $FH,'<',$ARGV[$v]);
+	open(my $FH,'<',$ARGV_copy[$v]);
 	my $geneprintswitch = 0;
 	
 	while(<$FH>){
 		$_=~s/[\r\n]+$//;
 
 		if($_ eq "" || length $_ < 2 || substr($_,0,1) eq "#"){next;}
-
+		
 		my $curLine=$_;
 
 		if(substr($curLine,0,1) eq $prefix ){
@@ -313,7 +329,6 @@ for(my $v = 0 ; $v < scalar @ARGV ; $v++){
 		}
 	}
 	close($FH);
-
 }
 
 if($cur_gene ne ""){
